package backend

import (
	"google.golang.org/grpc"
)

type Options struct {
	// Dial is an application supplied function for creating and configuring a
	// grpc connection.
	//
	// The grpc.ClientConn returned from Dial
	Dial func() (*grpc.ClientConn, error)

	// NewClient is an application supplied function for creating and configuring a
	// client.
	//
	// The client returned from NewClient
	NewClient func(*grpc.ClientConn) (interface{}, error)

	Exec func(client interface{}, target string, method string, params []string) (string, error)

	// Initial number of clients in the pool.
	InitCapacity int

	// Maximum number of clients allocated by the pool at a given time.
	// When zero, there is no limit on the number of clients in the pool.
	MaxCapacity int
}
